'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _ = require('../');

var _down_expand_blue = require('../assets/down_expand_blue2.svg');

var _down_expand_blue2 = _interopRequireDefault(_down_expand_blue);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Timings for animations
var SLIDE_DURATION = 0.3; // How long slide up/down takes
var DELAY_AFTER_SLIDE = -0.2; // Delay between sliding and options [dis]appearing
var FADE_DURATION = 0.05; // Duration each option fading in, next immediately starts after

var OptionDropdown = function OptionDropdown(_ref) {
  var handleClick = _ref.handleClick,
      id = _ref.id,
      isActive = _ref.isActive,
      options = _ref.options,
      value = _ref.value,
      width = _ref.width,
      zIndex = _ref.zIndex;

  // Creates an option box for use in dropdown. Consumes array `options` from props.
  var createSingleOptionBox = function createSingleOptionBox(optionValue, index, optionArray) {
    // Set up fade timings for dropdown options
    var fadeTransition = void 0;
    if (isActive) {
      // dropdown was just activated, need delays per each option
      var baseDelay = SLIDE_DURATION + DELAY_AFTER_SLIDE;
      var delayByIndex = FADE_DURATION * index;
      var totalDelay = baseDelay + delayByIndex;
      fadeTransition = 'opacity ' + FADE_DURATION + 's ' + totalDelay + 's linear';
    } else {
      // dropdown was just deactivated, no delay, just immediate fade out
      fadeTransition = 'opacity ' + FADE_DURATION + 's linear';
    }

    // Final option should have no border on bottom.
    var showBottomBorder = optionArray.length - 1 !== index;
    return _react2.default.createElement(
      _.ExtendedBox,
      {
        key: index,
        width: width,
        borderColor: 'gray.8',
        borderBottom: showBottomBorder ? '1px solid' : '0',
        opacity: isActive ? '1' : '0',
        transition: fadeTransition,
        id: id,
        onClick: handleClick,
        visibility: isActive ? 'visible' : 'hidden',
        value: value
      },
      _react2.default.createElement(
        _.Link,
        {
          type: 'L4',
          display: 'block',
          textAlign: 'center',
          width: width,
          value: optionValue,
          color: 'white',
          hoverColor: 'blue.2',
          m: 0,
          py: 20,
          visibility: isActive ? 'visible' : 'hidden',
          id: id,
          onClick: handleClick
        },
        optionValue
      )
    );
  };

  // Slide needs a delay depending on if going up or down. (Up goes after options)
  var slidingTransition = isActive ? 'max-height ' + SLIDE_DURATION + 's ease-in-out' : 'max-height ' + SLIDE_DURATION + 's ' + (FADE_DURATION + DELAY_AFTER_SLIDE) + 's ease-in-out';

  return _react2.default.createElement(
    _.ExtendedFlex,
    {
      width: width,
      id: id,
      onClick: handleClick,
      value: value,
      justify: 'center',
      position: 'relative',
      zIndex: isActive ? zIndex : '0',
      transition: isActive ? '0' : 'z-index 1s linear',
      borderColor: 'blue.2',
      borderBottom: '1px solid',
      hover: true
    },
    _react2.default.createElement(
      _.Heading,
      {
        type: 'H6',
        color: 'blue.2',
        m: 5,
        ml: -15,
        id: id,
        onClick: handleClick,
        value: value
      },
      value
    ),
    _react2.default.createElement(_.Image, {
      src: _down_expand_blue2.default,
      width: 13,
      height: 13,
      value: value,
      position: 'absolute',
      right: '5px',
      bottom: '10px',
      transition: 'transform 0.2s linear',
      transform: isActive ? 'rotate(180deg)' : 'none',
      id: id,
      onClick: handleClick,
      hover: true
    }),
    _react2.default.createElement(
      _.ExtendedFlex,
      {
        position: 'absolute',
        top: '100%',
        left: '0',
        mt: 1,
        bg: '#101010',
        flexDirection: 'column',
        align: 'center',
        width: width,
        maxHeight: isActive ? '500px' : '0',
        visibility: isActive ? 'visible' : 'hidden',
        transition: slidingTransition
      },
      options.map(createSingleOptionBox)
    )
  );
};

OptionDropdown.propTypes = {
  width: _propTypes2.default.array,
  zIndex: _propTypes2.default.string,
  value: _propTypes2.default.string,
  options: _propTypes2.default.array,
  isActive: _propTypes2.default.bool,
  handleClick: _propTypes2.default.func,
  id: _propTypes2.default.string
};

exports.default = OptionDropdown;