'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _numeral = require('numeral');

var _numeral2 = _interopRequireDefault(_numeral);

var _gridStyled = require('grid-styled');

var _ = require('../../../');

var _formatters = require('../../../helpers/formatters');

var _formatters2 = _interopRequireDefault(_formatters);

var _InvestmentTargetHold = require('./InvestmentTargetHold');

var _InvestmentTargetHold2 = _interopRequireDefault(_InvestmentTargetHold);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var calloutPosition1Generator = function calloutPosition1Generator(props) {
  var status = props.status,
      investmentTypeDisplay = props.investmentTypeDisplay,
      minimum = props.minimum,
      irrObjective = props.irrObjective,
      returnObjective = props.returnObjective;


  if (status === 'status-20-coming-soon') {
    return {
      label: 'Minimum',
      value: minimum ? (0, _numeral2.default)(minimum).format(_formatters2.default.SHORTENED_DOLLARS) : 'TBD'
    };
  } else if (status === 'status-30-active' || status === 'status-40-closed') {
    if (['Equity', 'Preferred Equity'].includes(investmentTypeDisplay)) {
      return {
        label: 'IRR Objective',
        value: (0, _numeral2.default)(irrObjective).format(_formatters2.default.PERCENTAGE2)
      };
    }
    if (investmentTypeDisplay === 'Debt') {
      return {
        label: 'Return Objective',
        value: (0, _numeral2.default)(returnObjective).format(_formatters2.default.PERCENTAGE2)
      };
    }
  }
  return {
    label: 'Minimum',
    value: (0, _numeral2.default)(minimum).format(_formatters2.default.SHORTENED_DOLLARS)
  };
};

var PropertyTypeData = function PropertyTypeData(_ref) {
  var distribution = _ref.distribution,
      distributionMoreInfo = _ref.distributionMoreInfo,
      propertyType = _ref.propertyType,
      reit = _ref.reit,
      distributionTooltip = _ref.distributionTooltip,
      id = _ref.id;

  return _react2.default.createElement(
    _react2.default.Fragment,
    null,
    _react2.default.createElement(
      _.Data,
      {
        type: 'D5',
        display: 'block',
        m: 0
      },
      reit ? distribution === null ? distributionMoreInfo : (0, _numeral2.default)(distribution).format(_formatters2.default.PERCENTAGE) : propertyType
    ),
    reit && distributionTooltip && _react2.default.createElement(_.TooltipIcon, {
      tooltipId: id + '_3x_position_3',
      ml: [2, 2, 5]
    })
  );
};

var PropertyTypeLabel = function PropertyTypeLabel(_ref2) {
  var reit = _ref2.reit;

  return _react2.default.createElement(
    _react2.default.Fragment,
    null,
    reit ? 'Distribution' : 'Property Type'
  );
};

var InvestmentCardCalloutsX3 = function InvestmentCardCalloutsX3(props) {
  var gtkyApproved = props.gtkyApproved,
      minimum = props.minimum,
      status = props.status,
      targetHoldMin = props.targetHoldMin,
      targetHoldMax = props.targetHoldMax,
      investmentTypeDisplay = props.investmentTypeDisplay,
      reit = props.reit,
      propertyType = props.propertyType,
      distribution = props.distribution,
      distributionMoreInfo = props.distributionMoreInfo,
      payoutLabel = props.payoutLabel,
      id = props.id,
      payoutTooltip = props.payoutTooltip,
      distributionTooltip = props.distributionTooltip;


  var limitedActiveCallout = status === 'status-30-active' && !gtkyApproved;

  return _react2.default.createElement(
    _gridStyled.Box,
    {
      pt: 10,
      px: 10
    },
    _react2.default.createElement(
      _gridStyled.Flex,
      {
        w: 1
      },
      _react2.default.createElement(
        _.ExtendedBox,
        {
          borderRight: 1,
          borderColor: 'gray.7',
          py: 10,
          w: 1
        },
        !limitedActiveCallout && _react2.default.createElement(
          _.Data,
          {
            type: 'D5',
            display: 'block',
            m: 0,
            textTransform: 'uppercase'
          },
          calloutPosition1Generator(props).value
        ),
        limitedActiveCallout && _react2.default.createElement(PropertyTypeData, {
          reit: reit,
          distribution: distribution,
          distributionMoreInfo: distributionMoreInfo,
          propertyType: propertyType,
          distributionTooltip: distributionTooltip,
          id: id
        }),
        _react2.default.createElement(
          _.Data,
          {
            pt: 5,
            type: 'D3',
            display: 'block',
            m: 0
          },
          !limitedActiveCallout && calloutPosition1Generator(props).label,
          limitedActiveCallout && _react2.default.createElement(PropertyTypeLabel, {
            reit: reit
          })
        )
      ),
      _react2.default.createElement(
        _.ExtendedBox,
        {
          borderRight: limitedActiveCallout ? 0 : 1,
          borderColor: 'gray.7',
          py: 10,
          pl: [10, 10, 20, 20, 20],
          w: [0.8, 0.8, 1, 1, 1],
          position: 'relative'
        },
        _react2.default.createElement(
          _gridStyled.Flex,
          {
            align: 'flex-end'
          },
          _react2.default.createElement(
            _.Data,
            {
              type: 'D5',
              m: 0
            },
            reit ? payoutLabel : _react2.default.createElement(_InvestmentTargetHold2.default, { min: targetHoldMin, max: targetHoldMax })
          ),
          reit && payoutTooltip && _react2.default.createElement(_.TooltipIcon, {
            tooltipId: id + '_3x_position_2',
            ml: [2, 2, 5]
          })
        ),
        _react2.default.createElement(
          _.Data,
          {
            pt: 5,
            type: 'D3',
            display: 'block',
            m: 0
          },
          reit ? 'Payout' : 'Target Hold'
        )
      ),
      _react2.default.createElement(
        _.ExtendedBox,
        {
          w: [0.9, 0.9, 1, 1, 1],
          py: 10,
          pl: [10, 10, 20, 20, 20]
        },
        _react2.default.createElement(
          _gridStyled.Flex,
          {
            align: 'flex-end'
          },
          !limitedActiveCallout && _react2.default.createElement(PropertyTypeData, {
            reit: reit,
            distribution: distribution,
            distributionMoreInfo: distributionMoreInfo,
            propertyType: propertyType,
            distributionTooltip: distributionTooltip,
            id: id
          })
        ),
        _react2.default.createElement(
          _.Data,
          {
            pt: 5,
            type: 'D3',
            display: 'block',
            m: 0
          },
          !limitedActiveCallout && _react2.default.createElement(PropertyTypeLabel, {
            reit: reit
          })
        )
      )
    )
  );
};

InvestmentCardCalloutsX3.propTypes = {
  minimum: _propTypes2.default.number,
  propertyType: _propTypes2.default.string,
  targetHoldMin: _propTypes2.default.number,
  targetHoldMax: _propTypes2.default.number,
  reit: _propTypes2.default.bool,
  payoutLabel: _propTypes2.default.string,
  distribution: _propTypes2.default.oneOfType([_propTypes2.default.number, _propTypes2.default.string]),
  distributionMoreInfo: _propTypes2.default.string,
  status: _propTypes2.default.string,
  investmentTypeDisplay: _propTypes2.default.string,
  id: _propTypes2.default.number,
  distributionTooltip: _propTypes2.default.string,
  payoutTooltip: _propTypes2.default.string,
  gtkyApproved: _propTypes2.default.bool,
  actualIrr: _propTypes2.default.number,
  irrObjective: _propTypes2.default.number,
  returnObjective: _propTypes2.default.number
};

InvestmentCardCalloutsX3.defaultProps = {
  propertyType: 'Placeholder',
  minimum: 10000,
  payoutLabel: 'Monthly',
  reit: false,
  targetHoldMin: 36,
  targetHoldMax: 60,
  distribution: 0.99,
  distributionMoreInfo: 'More Info',
  distributionTooltip: 'Placeholder distribution Tooltip',
  payoutTooltip: 'Placeholder payout Tooltip',
  gtkyApproved: true,
  irrObjective: 0.12,
  returnObjective: 0.09
};

exports.default = InvestmentCardCalloutsX3;