'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _numeral = require('numeral');

var _numeral2 = _interopRequireDefault(_numeral);

var _gridStyled = require('grid-styled');

var _ = require('../../../');

var _formatters = require('../../../helpers/formatters');

var _formatters2 = _interopRequireDefault(_formatters);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var InvestmentCardDataList = function InvestmentCardDataList(_ref) {
  var propertyType = _ref.propertyType,
      fundedDate = _ref.fundedDate,
      completedDate = _ref.completedDate,
      amountInvested = _ref.amountInvested,
      gtkyApproved = _ref.gtkyApproved,
      investmentTypeDisplay = _ref.investmentTypeDisplay,
      actualIrr = _ref.actualIrr;

  return _react2.default.createElement(
    _gridStyled.Flex,
    {
      flexDirection: 'column',
      pt: [20, 20, 40, 40, 60],
      w: 1
    },
    !gtkyApproved && investmentTypeDisplay === 'Debt' && _react2.default.createElement(
      _.ExtendedBox,
      {
        py: [10, 10, 15],
        px: 10,
        borderBottom: 1,
        borderColor: 'gray.7'
      },
      _react2.default.createElement(
        _gridStyled.Flex,
        {
          justify: 'space-between',
          align: 'center'
        },
        _react2.default.createElement(
          _.Data,
          {
            type: 'D2',
            color: 'gray.8',
            m: 0
          },
          'Return Objective'
        ),
        _react2.default.createElement(
          _.Data,
          {
            type: 'D3',
            color: 'gray.8',
            m: 0
          },
          (0, _numeral2.default)(actualIrr).format(_formatters2.default.PERCENTAGE2)
        )
      )
    ),
    _react2.default.createElement(
      _.ExtendedBox,
      {
        borderBottom: 1,
        borderColor: 'gray.7',
        p: 10
      },
      _react2.default.createElement(
        _gridStyled.Flex,
        {
          justify: 'space-between',
          align: 'center'
        },
        _react2.default.createElement(
          _.Data,
          {
            type: 'D2',
            color: 'gray.8',
            m: 0
          },
          'Property Type'
        ),
        _react2.default.createElement(
          _.Data,
          {
            type: 'D3',
            color: 'gray.8',
            m: 0
          },
          propertyType
        )
      )
    ),
    _react2.default.createElement(
      _.ExtendedBox,
      {
        borderBottom: 1,
        borderColor: 'gray.7',
        py: [10, 10, 15],
        px: 10
      },
      _react2.default.createElement(
        _gridStyled.Flex,
        {
          justify: 'space-between',
          align: 'center'
        },
        _react2.default.createElement(
          _.Data,
          {
            type: 'D2',
            color: 'gray.8',
            m: 0
          },
          'Funded'
        ),
        _react2.default.createElement(
          _.Data,
          {
            type: 'D3',
            color: 'gray.8',
            m: 0
          },
          (0, _moment2.default)(fundedDate).format(_formatters2.default.MMYYYY)
        )
      )
    ),
    _react2.default.createElement(
      _.ExtendedBox,
      {
        borderBottom: gtkyApproved ? 1 : 0,
        borderColor: 'gray.7',
        py: [10, 10, 15],
        px: 10
      },
      _react2.default.createElement(
        _gridStyled.Flex,
        {
          justify: 'space-between',
          align: 'center'
        },
        _react2.default.createElement(
          _.Data,
          {
            type: 'D2',
            color: 'gray.8',
            m: 0
          },
          'Completed'
        ),
        _react2.default.createElement(
          _.Data,
          {
            type: 'D3',
            color: 'gray.8',
            m: 0
          },
          (0, _moment2.default)(completedDate).format(_formatters2.default.MMYYYY)
        )
      )
    ),
    gtkyApproved && _react2.default.createElement(
      _.ExtendedBox,
      {
        py: [10, 10, 15],
        px: 10
      },
      _react2.default.createElement(
        _gridStyled.Flex,
        {
          justify: 'space-between',
          align: 'center'
        },
        _react2.default.createElement(
          _.Data,
          {
            type: 'D2',
            color: 'gray.8',
            m: 0
          },
          'Amount Invested'
        ),
        _react2.default.createElement(
          _.Data,
          {
            type: 'D3',
            color: 'gray.8',
            m: 0
          },
          (0, _numeral2.default)(amountInvested).format(_formatters2.default.DOLLARS)
        )
      )
    )
  );
};

// FIXME: Update proptypes when we know what types they are
InvestmentCardDataList.propTypes = {
  propertyType: _propTypes2.default.string,
  fundedDate: _propTypes2.default.string,
  completedDate: _propTypes2.default.string,
  amountInvested: _propTypes2.default.number,
  gtkyApproved: _propTypes2.default.bool,
  actualIrr: _propTypes2.default.number
};

InvestmentCardDataList.defaultProps = {
  propertyType: 'Theme Park',
  fundedDate: '1/2/3456',
  completedDate: '1/2/3456',
  amountInvested: 15000,
  actualIrr: 0.189
};

exports.default = InvestmentCardDataList;