'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _InvestmentCardContainer = require('../components/InvestmentCardContainer');

var _InvestmentCardContainer2 = _interopRequireDefault(_InvestmentCardContainer);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var containerFactoryFactory = function containerFactoryFactory(props) {
  var gtkyApproved = props.gtkyApproved,
      status = props.status,
      fadeIn = props.fadeIn,
      fadeIndex = props.fadeIndex,
      zIndex = props.zIndex,
      id = props.id,
      reit = props.reit,
      payoutTooltip = props.payoutTooltip,
      distributionTooltip = props.distributionTooltip,
      investmentTypeDisplay = props.investmentTypeDisplay,
      noAnimate = props.noAnimate;


  var containerFactory = function containerFactory(_ref) {
    var children = _ref.children,
        heights = _ref.heights;

    // Use a shorter card for completed / funded IOs. Switch between the shorter
    // types when the user is not GTKY approved for closed IOs.
    var heightKey = status === 'status-30-active' || status === 'status-40-closed' && !gtkyApproved ?
    // Show the mid card for Debt, not GTKY approved, and closed.
    investmentTypeDisplay === 'Debt' && !gtkyApproved && status === 'status-40-closed' ? 'mid' :
    // Otherwise, short cards for funded or completed deals without GTKY approval.
    'short' :
    // Default.
    'tall';
    var height = heights[heightKey];

    return _react2.default.createElement(
      _InvestmentCardContainer2.default,
      {
        height: height,
        fadeIn: fadeIn,
        fadeIndex: fadeIndex,
        reit: reit,
        zIndex: zIndex,
        id: id,
        payoutTooltip: payoutTooltip,
        distributionTooltip: distributionTooltip,
        noAnimate: noAnimate
      },
      children
    );
  };

  containerFactory.propTypes = {
    children: _propTypes2.default.any,
    heights: _propTypes2.default.shape({
      short: _propTypes2.default.oneOfType([_propTypes2.default.number, _propTypes2.default.array]),
      mid: _propTypes2.default.oneOfType([_propTypes2.default.number, _propTypes2.default.array]),
      tall: _propTypes2.default.oneOfType([_propTypes2.default.number, _propTypes2.default.array])
    })
  };

  containerFactory.defaultProps = {
    heights: {
      short: [375, 375, 500, 500, 610],
      mid: [405, 405, 550, 550, 660],
      tall: [550, 550, 700, 700, 780]
    }
  };

  return containerFactory;
};

exports.default = containerFactoryFactory;