'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.whichEndEvent = exports.whichStartEvent = exports.extendDefaultTransition = exports.hoverBorderColor = exports.hoverBackgroundColor = exports.hoverColor = exports.hoverRemoveFilterEffect = exports.hoverShadowEffect = exports.responsiveBackgroundSize = exports.height = undefined;

var _styledSystem = require('styled-system');

// @FIXME: This is to be deprecrated since styled-system
// now has a height function that is the same.
var height = exports.height = (0, _styledSystem.responsiveStyle)({
  prop: 'height',
  cssProperty: 'height',
  numberToPx: true
});

var responsiveBackgroundSize = exports.responsiveBackgroundSize = (0, _styledSystem.responsiveStyle)({
  prop: 'responsiveBackgroundSize',
  alias: 'rbgSize',
  cssProperty: 'background-size'
});

var hoverShadowEffect = exports.hoverShadowEffect = '0 6px 14px rgba(0,0,0,0.05), 0 6px 10px rgba(0,0,0,0.05)';
var hoverRemoveFilterEffect = exports.hoverRemoveFilterEffect = '\n  img {\n    filter: none;\n  }\n';

// Custom styles for hover (hover not part of styled-system)
var hoverColor = exports.hoverColor = (0, _styledSystem.style)({
  prop: 'hoverColor', // Prop name being passed in
  cssProperty: 'color', // CSS property targeted
  key: 'colors' // key for `Theme.js`, pulling from same pool of colors
});
var hoverBackgroundColor = exports.hoverBackgroundColor = (0, _styledSystem.style)({
  prop: 'hoverBG',
  cssProperty: 'background-color',
  key: 'colors'
});
var hoverBorderColor = exports.hoverBorderColor = (0, _styledSystem.style)({
  prop: 'hoverBorderColor',
  cssProperty: 'border-color',
  key: 'colors'
});

// animation related
var endEvents = {
  animation: 'animationend',
  OAnimation: 'oAnimationEnd',
  MozAnimation: 'animationend',
  WebkitAnimation: 'webkitAnimationEnd'
};

var startEvents = {
  animation: 'animationstart',
  OAnimation: 'oAnimationStart',
  MozAnimation: 'animationStart',
  WebkitAnimation: 'webkitAnimationStart'
};

function whichEvent(events) {
  var el = document.createElement('fakeelement');
  for (var t in events) {
    if (el.style[t] !== undefined) {
      return events[t];
    }
  }
}

// Adds on to default transition (mainly intended for Links/NavLinks)
// INPUT1: str (or undefined), a legit CSS shorthand 'transition' property
// INPUT2 [optional]: str, CSS transition for the intended default [uses link default]
// OUTPUT: str, CSS transition incorporating desired default behavior
// NOTE: this is needed because we regularly pass transition props, but we want to
// avoid completely stomping out the desired default transition.
// This enables us to keep default, but can tweak by re-passing `color ...`, etc.
// NOTE: If you want to DISABLE transition ENTIRELY, can pass "all 0s"
var extendDefaultTransition = exports.extendDefaultTransition = function extendDefaultTransition(additionalTransition) {
  var defaultTransition = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "color 0.5s linear, background-color 0.5s linear, border-color 0.5s linear";

  // We start with the default transition, modify based on what was passed.
  var transition = defaultTransition;
  if (additionalTransition) {
    transition = transition + (', ' + additionalTransition);
  }
  return transition;
};

var whichStartEvent = exports.whichStartEvent = function whichStartEvent() {
  return whichEvent(startEvents);
};
var whichEndEvent = exports.whichEndEvent = function whichEndEvent() {
  return whichEvent(endEvents);
};