import React from 'react';
import PropTypes from 'prop-types';

import {
  ExtendedFlex,
  ExtendedBox,
  Accordion,
} from '../../../';

import AccordionHeading from './AccordionHeading';

class AccordionWithTopic extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      activeIndexes: [],
    };

    this.toggleAccordion = this.toggleAccordion.bind(this);
  }

  toggleAccordion(id) {
    this.setState({
      activeIndexes: this.state.activeIndexes.includes(id) ?
        this.state.activeIndexes.filter(
          (i) => {
            return i !== id;
          },
        ) :
      [
        ...this.state.activeIndexes,
        id,
      ],
    });
  }

  render() {
    const {
      items,
      contentIsHtml,
    } = this.props;

    const {
      activeIndexes,
    } = this.state;

    return (
      <ExtendedFlex
        flexDirection="column"
        justify="center"
        align="center"
        pt={20}
        w={1}
      >
        {
          items.map(
            (item) => {
              const isActive = activeIndexes.includes(item.id);

              return (
                <ExtendedFlex
                  key={item.id}
                  flexDirection="column"
                  justify="center"
                  w={1}
                  align="center"
                  mt={5}
                >
                  <ExtendedBox
                    bg="white"
                    w={1}
                    py={20}
                  >
                    <AccordionHeading
                      content={item.topic}
                      id={item.id}
                      isActive={isActive}
                      handleClick={this.toggleAccordion}
                      isUppercase
                    />
                  </ExtendedBox>
                  {
                    isActive &&
                      <Accordion
                        items={item.items}
                        contentIsHtml={contentIsHtml}
                      />
                  }
                </ExtendedFlex>
              );
            },
          )
        }
      </ExtendedFlex>
    );
  }
}

AccordionWithTopic.propTypes = {
  items: PropTypes.array,
  contentIsHtml: PropTypes.bool,
};

export default AccordionWithTopic;
